Filter out aarch64 just like x86_64 for unknown arch.

This fixes rebuild-all-prebuilt.sh building process.

Change-Id: Ia98952ad0d5c93923fb4dfe0626969ecb5bc413a
diff --git a/build/tools/prebuilt-common.sh b/build/tools/prebuilt-common.sh
index d659334..79e9409 100644
--- a/build/tools/prebuilt-common.sh
+++ b/build/tools/prebuilt-common.sh
@@ -1183,9 +1183,9 @@
 find_ndk_unknown_archs()
 {
     local FOUND_ARCHS=$(find_ndk_archs)
     # TODO: x86_64 is here just to be found as known arch.
     # It can be removed as soon as it is added into $DEFAULT_ARCHS
-    echo "$(filter_out "$DEFAULT_ARCHS x86_64" "$FOUND_ARCHS")"
+    echo "$(filter_out "$DEFAULT_ARCHS aarch64 x86_64" "$FOUND_ARCHS")"
 }
 
 # Determine whether given arch is in unknown archs list
@@ -1183,9 +1183,9 @@
 {
     local FOUND_ARCHS=$(find_ndk_archs)
-    # TODO: x86_64 is here just to be found as known arch.
+    # TODO: aarch64, x86_64 is here just to be found as known arch.
     # It can be removed as soon as it is added into $DEFAULT_ARCHS